% Commercial method click-detection test evaluation
% Authors: Frantisek Rund, Marek Semansk, Vclav Vencovsk 
% FEE CTU 2021
% MATLAB Version: 9.4.0.813654 (R2018a)


clear all, close all, clc
data = xlsread('table_results.xlsx'); %results of click-detection test of commercial methods loaded
load('subj_results.mat'); %results of listening test loaded

subjRes = vysledky(:,2)/100;

idxHIT = find(subjRes>=0.75); %marked as containing clicks > 75 %
idxNO = find(subjRes<=0.25); %marked as containing clicks < 75 %

kstim = sort([idxHIT;idxNO]); % %"Unsure" samples removed (25 % - 75 %)

clickW1=data(:,9); %first setting "Click Detection"
clickW2=data(:,10); %second setting "Sensitive Detection"
clickW3=data(:,11); %third setting "Very Sensitive Detection"

%% click

ErrorRate = 100-(sum(clickW1(idxHIT))/length(idxHIT))*100; 
CD=100-ErrorRate; % Hit
FA = sum(abs(clickW1(idxNO)))/length(idxNO)*100; % False Alarm
total = ErrorRate + FA;
dprime=(norminv(CD/100)-norminv(FA/100));
disp(['Wavelab Click Detection'])
disp(['Not detected: ' num2str(ErrorRate) '%'])
disp(['Correctly detected: ' num2str(CD) '%'])
disp(['False detected: ' num2str(FA) '%'])
disp(['d prime: ' num2str(dprime) ])
disp(['----------------------------'])

figure
bar(idxHIT,clickW1(idxHIT))
hold on
bar(idxNO,abs(clickW1(idxNO)))
plot(idxHIT,subjRes(idxHIT),'-*')
plot(idxNO,subjRes(idxNO),'-*')
title('click det')


%% sensitive
ErrorRate = 100-(sum(clickW2(idxHIT))/length(idxHIT))*100; 
CD=100-ErrorRate; % Hit
FA = sum(abs(clickW2(idxNO)))/length(idxNO)*100; % False Alarm
total = ErrorRate + FA;
dprime=(norminv(CD/100)-norminv(FA/100));
disp(['Wavelab Sensitive Detection'])
disp(['Not detected: ' num2str(ErrorRate) '%'])
disp(['Correctly detected: ' num2str(CD) '%'])
disp(['False detected: ' num2str(FA) '%'])
disp(['d prime: ' num2str(dprime) ])
disp(['----------------------------'])

figure
bar(idxHIT,clickW2(idxHIT))
hold on
bar(idxNO,abs(clickW2(idxNO)))
plot(idxHIT,subjRes(idxHIT),'-*')
plot(idxNO,subjRes(idxNO),'-*')
title('sensitive')




%% very sensitive
ErrorRate = 100-(sum(clickW3(idxHIT))/length(idxHIT))*100; 
CD=100-ErrorRate; % Hit
FA = sum(abs(clickW3(idxNO)))/length(idxNO)*100; % False Alarm
total = ErrorRate + FA;
dprime=(norminv(CD/100)-norminv(FA/100));
disp(['Wavelab Very Sensitive Detection'])
disp(['Not detected: ' num2str(ErrorRate) '%'])
disp(['Correctly detected: ' num2str(CD) '%'])
disp(['False detected: ' num2str(FA) '%'])
disp(['d prime: ' num2str(dprime) ])
disp(['----------------------------'])

figure
bar(idxHIT,clickW3(idxHIT))
hold on
bar(idxNO,abs(clickW3(idxNO)))
plot(idxHIT,subjRes(idxHIT),'-*')
plot(idxNO,subjRes(idxNO),'-*')
title('very sens')


