% Wavelet based click-detection test
% Authors: Vclav Vencovsk, Marek Semansk, Frantisek Rund
% FEE CTU 2021
% MATLAB Version: 9.4.0.813654 (R2018a)

clear
addpath('fce_wavelet');  % add path to folder with wavelet click detection functions
%subjective test results loading
load('subj_results.mat');
subjRes = vysledky(:,2)/100;

idxHIT = find(subjRes>=0.75); %marked as containing clicks > 75 %
idxNO = find(subjRes<=0.25); %marked as containing clicks < 75 %

kstim = sort([idxHIT;idxNO]); % %"Unsure" samples removed (25 % - 75 %)
%kstim=1:length(subjRes); %all samples

%Folder with the samples
FolderName = 'ScratchStimuliTest/';
listWav = dir(FolderName);


%detection parameters
LengthFilt = [150]; %Median filter window length L !
Threshold = [25]; %Detection threshold gain K !
vlnka = ['db30']; %wavelet type and order

idxLup = 17640; % Starting position for the detection - half of the signal (sample) length
idxTol = idxLup-1; % Range for click detection - half of the signal (sample) length - a click is searched in full length of the sample


clickWM = zeros(length(listWav)-2,1); %preallocation of detection vector

        
disp(['Median filter window L: ' num2str(LengthFilt) ', Detection threshold parameter K: ' num2str(Threshold) ', Wavelet: ' num2str(vlnka)]) %zobrazeni parametru detekce

    for k=1:length(kstim) %detection cycle
    
        [y fs] = audioread([FolderName listWav(kstim(k)+2).name]); %sample loading

         y = y(:,1); %only left channel used for the subjective test 

       %detection based on wavelet transform
        if min(abs(idxHIT-kstim(k)))==0
            clickWM(kstim(k)) = vlnkova_segment_mm( y, vlnka, Threshold, LengthFilt,idxLup,idxTol,1);
        else
            clickWM(kstim(k)) = vlnkova_segment_mm( y, vlnka, Threshold, LengthFilt,idxLup,idxTol,0);
        end
    end
    
    %evaluation
    ErrorRate = (1-sum(clickWM(idxHIT))/length(idxHIT))*100; 
    CD=100-ErrorRate; %% Hit
    FA = (sum(clickWM(idxNO))/length(idxNO))*100; % False Alarm
    total = (ErrorRate + FA); 
    dprime=(norminv(CD/100)-norminv(FA/100));
    disp(['Not detected: ' num2str(ErrorRate) '%'])
disp(['Correctly detected: ' num2str(CD) '%'])
disp(['False detected: ' num2str(FA) '%'])
disp(['d prime: ' num2str(dprime) ])
disp(['----------------------------'])
 
figure
bar(idxHIT,clickWM(idxHIT))
hold on
bar(idxNO,abs(clickWM(idxNO)))
plot(idxHIT,subjRes(idxHIT),'-*')
plot(idxNO,subjRes(idxNO),'-*')
title('WM')

rmpath('fce_wavelet');