% matched filter based click-detection test
% Authors: Vclav Vencovsk, Marek Semansk, Frantisek Rund
% FEE CTU 2021
% MATLAB Version: 9.4.0.813654 (R2018a)

clear, close all, %clc

addpath('fce_matched');  % add path to folder with matched filter click detection functions
%subjective test results loading
load('subj_results.mat');
subjRes = vysledky(:,2)/100;


idxHIT = find(subjRes>=0.75); %marked as containing clicks > 75 %
idxNO = find(subjRes<=0.25); %marked as containing clicks < 75 %

%Folder with the samples
FolderName = 'ScratchStimuliTest/';
listWav = dir(FolderName);

%detection parameters
LengthSeg = 6144; %Frame length N !
Threshold = 35; %Detection threshold gain K !
Order = 30; %Prediction order P

idxLup = 17640; % Starting position for the detection - half of the signal (sample) length
idxTol = idxLup-1; % Range for click detection - half of the signal (sample) length - a click is searched in full length of the sample

kstim = sort([idxHIT;idxNO]); %"Unsure" samples removed (25 % - 75 %)
%kstim=1:length(subjRes); %all samples
disp(['Frame length N: ' num2str(LengthSeg) ', Detection threshold parameter K: ' num2str(Threshold) ', Prediction order p: ' num2str(Order)]) %zobrazeni parametru detekce

%-------------------------------------------------------------------------------------------------
for k=1:length(kstim) %%detection for cycle
    %-------------------------------------------------------------------------------------------------
    [y, fs] = audioread([FolderName listWav(kstim(k)+2).name]); %sample loading

    y = y(:,1); %only left channel used for the subjective test 
    
    if min(abs(idxHIT-kstim(k)))==0 %matched filter
          
          clickAR(kstim(k)) = match_filter_mm(y, Order, Threshold, LengthSeg,idxLup,idxTol,1);%click perceived
    else
          clickAR(kstim(k)) = match_filter_mm(y, Order, Threshold, LengthSeg,idxLup,idxTol,0);%click not perceived
    end    
end
%evaluation
ErrorRate = 100-(sum(clickAR(idxHIT))/length(idxHIT))*100; 
CD=100-ErrorRate; %Hit
FA = sum(abs(clickAR(idxNO)))/length(idxNO)*100; % False Alarm
total = ErrorRate + FA;
dprime=(norminv(CD/100)-norminv(FA/100));

disp(['Not detected: ' num2str(ErrorRate) '%'])
disp(['Correcty detected: ' num2str(CD) '%'])
disp(['False detected: ' num2str(FA) '%'])
disp(['d prime: ' num2str(dprime) ])
disp(['----------------------------'])


figure
bar(idxHIT,clickAR(idxHIT))
hold on
bar(idxNO,abs(clickAR(idxNO)))
plot(idxHIT,subjRes(idxHIT),'-*')
plot(idxNO,subjRes(idxNO),'-*')
title('matched')

rmpath('fce_matched');